Documentation
¶
Overview ¶
Package editor lints open buffers for editor integrations.
Index ¶
- func Diagnose(path string, content []byte, workingDir string) ([]diagnostic.Diagnostic, error)
- func DiagnoseContextWithCache(ctx context.Context, path string, content []byte, workingDir string, ...) ([]diagnostic.Diagnostic, error)
- func DiagnoseWithCache(path string, content []byte, workingDir string, cache *project.ParseCache, ...) ([]diagnostic.Diagnostic, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Diagnose ¶
func Diagnose(path string, content []byte, workingDir string) ([]diagnostic.Diagnostic, error)
Diagnose lints content as path using configuration found from workingDir.
func DiagnoseContextWithCache ¶ added in v1.4.0
func DiagnoseContextWithCache( ctx context.Context, path string, content []byte, workingDir string, cache *project.ParseCache, shared *analysis.Result, ) ([]diagnostic.Diagnostic, error)
DiagnoseContextWithCache stops before lint rules when ctx is cancelled.
func DiagnoseWithCache ¶ added in v1.1.6
func DiagnoseWithCache(path string, content []byte, workingDir string, cache *project.ParseCache, shared *analysis.Result) ([]diagnostic.Diagnostic, error)
DiagnoseWithCache lints content as path using configuration found from workingDir. It reuses cached includes and shared analysis facts when supplied. Nil arguments behave like Diagnose.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.